pilas.actores.mapatiled.MapaTiled

Package pilas :: Package actores :: Module mapatiled :: Class MapaTiled |
[hide private]
[frames] | no frames]

# Class MapaTiled

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                        mapa.Mapa --+
                                    |
                                   MapaTiled

Representa mapas creados a partir de imagenes mas pequeñas.

Este actor te permite crear escenarios tipo ``tiles``, a partir de archivos .tmx, creados con el programa **tiled** (ver http://www.mapeditor.org).

Por ejemplo, para crear un mapa desde un archivo del programa **tiled** puedes escribir:

    >>> mapa = pilas.actores.MapaTiled('untitled2.tmx')

Tiled trabaja con capas, así que cuando pilas carga las capas las interpreta de la siguiente manera:

- La capa 0 define los bloques no sólidos, generalmente fondos o decoración.
- La capa 1 define bloques sólidos, útiles para hacer suelos o paredes.
- Las siguientes capas solo se almacenan, pero no se dibujan. Se pueden acceder con ``mapa.capas``.

Instance Methods | [hide private]
__init__(self, ruta_mapa, x=0, y=0, restitucion=0.56) Inicializa el mapa. | source code
cuadro_ancho(self) Retorna el ancho de un bloque del mapa | source code
cuadro_alto(self) Retorna el alto de un bloque del mapa | source code
_cargar_datos_basicos_del_mapa(self, archivo) | source code
_dibujar_mapa(self, archivo) | source code
_pintar_bloques(self, capa, solidos) Genera actores que representan los bloques del escenario. | source code
_convertir_capa_en_bloques_enteros(self, capa) | source code
Inherited from `mapa.Mapa`: `convertir_de_coordenada_absoluta_a_coordenada_mapa`, `es_bloque_solido`, `es_punto_solido`, `es_punto_solido_coordenada_mapa`, `obtener_distancia_al_suelo`, `obtener_numero_de_columna`, `obtener_numero_de_fila`, `pintar_bloque`, `pintar_limite_de_bloques` Inherited from `mapa.Mapa` (private): `_convertir_en_int`, `_generar_matriz_de_bloques`, `_pintar_borde_de_grilla` Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ruta_mapa, x=0, y=0, restitucion=0.56) (Constructor) | source code
Inicializa el mapa. :param grilla: La imagen a utilizar cómo grilla con los bloques del escenario. :param x: Posición horizontal del mapa. :param y: Posición vertical del mapa. :param filas: Cantidad de filas que tendrá el mapa. :param columnas: Cantidad de columnas que tendrá el mapa. Overrides: estudiante.Estudiante.__init__ (inherited documentation)

### _pintar_bloques(self, capa, solidos) | source code
Genera actores que representan los bloques del escenario. Retorna una lista de los bloques convertidos a numeros.